# libpythonpro
Módulo para exemplificar construção de projetos python no curso PyTools

.
Suportada a versão do python 3


Para instalar 
'''console
python3 -m venv .venv
source .venv/bin/activate
pip install -r requirements-dev.txt
'''

Para conferir qualidade do código
"""console
flake8
"""

Link: https://pythonpro.com.br/

[![Build Status](https://app.travis-ci.com/Heber3000/libpythonpro.svg?branch=master)](https://app.travis-ci.com/Heber3000/libpythonpro)
[![Updates](https://pyup.io/repos/github/Heber3000/libpythonpro/shield.svg)](https://pyup.io/repos/github/Heber3000/libpythonpro/)
[![Python 3](https://pyup.io/repos/github/Heber3000/libpythonpro/python-3-shield.svg)](https://pyup.io/repos/github/Heber3000/libpythonpro/)
=========
Tópico:

1.Git
2.Virtualenv
3.Pip
=======

.Link do curso pythonpro:https://pythonpro.com.br/









